#[non_exhaustive]pub struct UpdateNamedQueryInputBuilder { /* private fields */ }Expand description
A builder for UpdateNamedQueryInput.
Implementations
Sourceimpl UpdateNamedQueryInputBuilder
impl UpdateNamedQueryInputBuilder
Sourcepub fn named_query_id(self, input: impl Into<String>) -> Self
pub fn named_query_id(self, input: impl Into<String>) -> Self
The unique identifier (UUID) of the query.
This field is required.Sourcepub fn set_named_query_id(self, input: Option<String>) -> Self
pub fn set_named_query_id(self, input: Option<String>) -> Self
The unique identifier (UUID) of the query.
Sourcepub fn get_named_query_id(&self) -> &Option<String>
pub fn get_named_query_id(&self) -> &Option<String>
The unique identifier (UUID) of the query.
Sourcepub fn name(self, input: impl Into<String>) -> Self
pub fn name(self, input: impl Into<String>) -> Self
The name of the query.
This field is required.Sourcepub fn description(self, input: impl Into<String>) -> Self
pub fn description(self, input: impl Into<String>) -> Self
The query description.
Sourcepub fn set_description(self, input: Option<String>) -> Self
pub fn set_description(self, input: Option<String>) -> Self
The query description.
Sourcepub fn get_description(&self) -> &Option<String>
pub fn get_description(&self) -> &Option<String>
The query description.
Sourcepub fn query_string(self, input: impl Into<String>) -> Self
pub fn query_string(self, input: impl Into<String>) -> Self
The contents of the query with all query statements.
This field is required.Sourcepub fn set_query_string(self, input: Option<String>) -> Self
pub fn set_query_string(self, input: Option<String>) -> Self
The contents of the query with all query statements.
Sourcepub fn get_query_string(&self) -> &Option<String>
pub fn get_query_string(&self) -> &Option<String>
The contents of the query with all query statements.
Sourcepub fn build(self) -> Result<UpdateNamedQueryInput, BuildError>
pub fn build(self) -> Result<UpdateNamedQueryInput, BuildError>
Consumes the builder and constructs a UpdateNamedQueryInput.
Sourceimpl UpdateNamedQueryInputBuilder
impl UpdateNamedQueryInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<UpdateNamedQueryOutput, SdkError<UpdateNamedQueryError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<UpdateNamedQueryOutput, SdkError<UpdateNamedQueryError, HttpResponse>>
Sends a request with this input using the given client.